django-siteflags documentation
==============================
https://github.com/idlesign/django-siteflags



Description
-----------

*Reusable application for Django allowing users to flag/bookmark site objects*


So you want a user to be able to put some flags on certain site entities.

Let's say you need a kind of bookmark powered service, or a site where content is flagged and moderated, or a simplified rating system or something similar.



Requirements
------------

.. image:: https://idlesign.github.io/lbc/py2-lbc.svg
   :target: https://idlesign.github.io/lbc/
   :alt: LBC Python 2

----

1. Python 2.7+, 3.5+
2. Django 1.7+
3. Django Auth contrib enabled
4. Django Admin contrib enabled (optional)


Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart
    models



Get involved into django-siteflags
----------------------------------

**Submit issues.** If you spotted something weird in application behavior or want to propose a feature you can do that at https://github.com/idlesign/django-siteflags/issues

**Write code.** If you are eager to participate in application development, fork it at https://github.com/idlesign/django-siteflags, write your code, whether it should be a bugfix or a feature implementation, and make a pull request right from the forked project page.

**Translate.** If want to translate the application into your native language use Transifex: https://www.transifex.com/projects/p/django-siteflags/.

**Spread the word.** If you have some tips and tricks or any other words in mind that you think might be of interest for the others — publish them.



Also
----

If the application is not what you want for content flagging/bookmarking, you might be interested in considering other choices — https://www.djangopackages.com/grids/g/bookmarking/
